@@ -3,17 +3,13 @@
      /***************************************************
       *  Disk Quota Plugin                              *
       *  By Kerem Erkan <kerem.erkan@hacettepe.edu.tr>  *
-      *  Version 3.0.3                                  *
+      *  Version 3.1                                    *
       *  See INSTALL for usage details.                 *
       ***************************************************/
 
-/* Set the SM_PATH for use with 1.4.x */
-
-if (!defined('SM_PATH'))
-    {
-      define('SM_PATH' , '../');
-      chdir ("..");
-    }
+if ( !defined('SM_PATH') ) {
+    define('SM_PATH', '../../');
+}
 
 include_once (SM_PATH . 'plugins/disk_quota/config.php');
 
