@@ -3,7 +3,7 @@
      /***************************************************
       *  Disk Quota Plugin                              *
       *  By Kerem Erkan <kerem.erkan@hacettepe.edu.tr>  *
-      *  Version 3.0.3                                  *
+      *  Version 3.1                                    *
       *  See INSTALL for usage details.                 *
       ***************************************************/
 
@@ -63,6 +63,12 @@ if ( sizeof($quota_data) > 2 ) {
                 if ( $dq_show_filesystem == 0 ) {
                         $dq_fsname = "-";
                 }
+                else {
+                        if ( !empty($dq_fs_alias) ) {
+                                $dq_fsname = $dq_fs_alias[$dq_fsname];
+                                $dq_fsname = str_replace("+", " ", $dq_fsname);
+                        }
+                }
                 $dq_blocks = str_replace("*", "", $dq_blocks);
                 $dq_grace = str_replace("day", ":day", $dq_grace);
                 if ( $dq_blocks < $dq_quota ) {
