@@ -2,10 +2,6 @@
 
 function disk_quota_check() {
 
-    if ( !defined('SM_PATH') ) {
-        define('SM_PATH', '../');
-    }
-
     include_once(SM_PATH . 'plugins/disk_quota/config.php');
     include_once(SM_PATH . 'functions/i18n.php');
     bindtextdomain('disk_quota', SM_PATH . 'plugins/disk_quota/locale');
