@@ -6,11 +6,11 @@ function squirrelmail_plugin_init_disk_quota() {
 }
 
 function disk_quota_version() {
-    return '3.0.3';
+    return '3.1';
 }
 
 if ( !defined('SM_PATH') ) {
-    define('SM_PATH', '../');
+    define('SM_PATH', '../../');
 }
 
 function disk_quota_graph_and_details() {
